@@ -112,8 +112,7 @@ export class QwcArcBeans extends LitElement {
                         ${bean.nonDefaultQualifiers.map(qualifier =>
                             html`${this._qualifierRenderer(qualifier)}`
                         )}
-                        <qui-ide-link fileName='${bean.providerType.name}'
-                            lineNumber=0><code>${bean.providerType.name}</code></qui-ide-link>
+                        <qui-ide-link fileName='${bean.providerType.name}'><code>${bean.providerType.name}</code></qui-ide-link>
       
                     </vaadin-vertical-layout>`;
     }
@@ -193,4 +192,4 @@ export class QwcArcBeans extends LitElement {
         });
     }
 }
-customElements.define('qwc-arc-beans', QwcArcBeans);
\ No newline at end of file
+customElements.define('qwc-arc-beans', QwcArcBeans);
